//
//  ViewController.swift
//  ChartsBug
//
//  Created by John Scalo on 5/3/17.
//  Copyright © 2017 John Scalo. All rights reserved.
//

import UIKit
import Charts

class ViewController: UIViewController {

    @IBOutlet weak var chart: LineChartView!
    @IBOutlet weak var removeTextField: UITextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.configureChart()
    }

    @IBAction func addData(_ sender: Any) {
        if let set1 = self.chart.data?.dataSets.first {

            let val = arc4random_uniform(20) + 80
            let cnt = set1.entryCount
            _ = set1.addEntry(ChartDataEntry(x: Double(cnt), y: Double(val)))
            self.chart.data?.notifyDataChanged()
            self.chart.notifyDataSetChanged()
        }
    }

    @IBAction func removeIndex(_ sender: Any) {
        if let set1 = self.chart.data?.dataSets.first {
            _ = set1.removeEntry(index: Int(self.removeTextField.text!)!)
            self.chart.data?.notifyDataChanged()
            self.chart.notifyDataSetChanged()
        }
    }
    
    private func configureChart() {
        self.chart.chartDescription?.enabled = false
        self.chart.dragEnabled = true
        self.chart.setScaleEnabled(true)
        self.chart.pinchZoomEnabled = true
        self.chart.scaleYEnabled = false
        self.chart.drawMarkers = false
        self.chart.drawBordersEnabled = false
        self.chart.drawGridBackgroundEnabled = false
        self.chart.minOffset = 0
        self.chart.extraTopOffset = 30 // to account for our relatively large labels
        self.chart.highlightPerTapEnabled = false
        self.chart.highlightPerDragEnabled = false
        self.chart.noDataText = ""
        
        // Limit the amount of x axis zooming
        self.chart.setScaleMinima(0.1, scaleY: 1.0)
        
        // Configure x axis
        self.chart.xAxis.enabled = true
        self.chart.xAxis.drawLabelsEnabled = false
        self.chart.xAxis.drawGridLinesEnabled = true
        self.chart.xAxis.drawAxisLineEnabled = false
        self.chart.xAxis.granularityEnabled = true
        self.chart.xAxis.granularity = 1
        self.chart.xAxis.gridColor = UIColor.black
        
        // Configure y axis
        self.chart.leftAxis.axisMaximum = 100
        self.chart.leftAxis.axisMinimum = 80
        self.chart.leftAxis.enabled = false
        self.chart.rightAxis.enabled = false

        let set1 = LineChartDataSet(values: [], label: "")
        set1.drawIconsEnabled = false
        set1.drawCirclesEnabled = false
        set1.lineWidth = 0.0
        set1.drawCircleHoleEnabled = false
        set1.valueFont = UIFont.systemFont(ofSize: 17)
        
        set1.fillAlpha = 1.0
        let colors = [UIColor.red.cgColor, UIColor.blue.cgColor] as CFArray
        let gradient = CGGradient(colorsSpace: nil, colors: colors, locations: nil)
        set1.fill = Fill(linearGradient: gradient!, angle: 90.0)
        set1.drawFilledEnabled = true
        
        let data = LineChartData(dataSet: set1)
        self.chart.data = data
    }
}

